@@ -45,8 +45,8 @@ log = logging.getLogger(__name__)
 
 class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMixin, BaseFinetuning):
     r"""
-    This callback enables flexible, multi-phase, scheduled fine-tuning of foundational models. Gradual
-    unfreezing/thawing can help maximize foundational model knowledge retention while allowing (typically upper layers
+    This callback enables flexible, multi-phase, scheduled fine-tuning of foundation models. Gradual
+    unfreezing/thawing can help maximize foundation model knowledge retention while allowing (typically upper layers
     of) the model to optimally adapt to new tasks during transfer learning.
     :class:`~finetuning_scheduler.fts.FinetuningScheduler` orchestrates the gradual unfreezing of models via a
     fine-tuning schedule that is either implicitly generated (the default) or explicitly provided by the user (more
@@ -139,7 +139,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 with may be included. Additionally, one may optionally include arguments to pass to PyTorch Lightning's
                 lr scheduler configuration :class:`~pytorch_lightning.utilities.types.LRSchedulerConfig` in the
                 ``pl_lrs_cfg`` dictionary. By way of example, one could configure this dictionary via the
-                :external+pl:class:`~pytorch_lightning.utilities.cli.LightningCLI` with the following:
+                :external+pl:class:`~pytorch_lightning.cli.LightningCLI` with the following:
 
                 .. code-block:: yaml
 
@@ -265,6 +265,13 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         assert self._fts_state._ft_sync_objects is not None
         FinetuningScheduler.sync(self._fts_state._ft_sync_objects, self._fts_state._ft_sync_props)
         rank_zero_info(f"Multi-phase fine-tuned training continuing at level {self.curr_depth}.")
+        if self.depth_remaining == 0:
+            max_epochs_msg = f"`max_epochs` ({self.pl_module.trainer.fit_loop.max_epochs}) is reached."
+            composition_msg = "the early stopping conditions are met or " + max_epochs_msg
+            rank_zero_info(
+                f"Given the current configuration of `max_depth` ({self.max_depth}), this training session"
+                f" will now end when {max_epochs_msg if self.epoch_transitions_only else composition_msg}"
+            )
 
     def step_pg(self, optimizer: Optimizer, depth: int, depth_sync: bool = True) -> None:
         """Configure optimizer parameter groups for the next scheduled fine-tuning level, adding parameter groups
